@@ -10,15 +10,17 @@ knitr::opts_chunk$set(
 library("RprobitB")
 options("RprobitB_progress" = FALSE)
 
-## ----message = FALSE----------------------------------------------------------
+## ----elec-model, message = FALSE----------------------------------------------
 data("Electricity", package = "mlogit")
-Electricity <- as_cov_names(Electricity, c("pf", "cl", "loc", "wk", "tod", "seas"), 1:4)
+Electricity <- as_cov_names(
+  Electricity, c("pf", "cl", "loc", "wk", "tod", "seas"), 1:4
+)
 data <- prepare_data(
   form = choice ~ pf + cl + loc + wk + tod + seas | 0,
   choice_data = Electricity,
   re = c("cl", "loc", "wk", "tod", "seas")
 )
-model_elec <- fit_model(data, R = 1000, scale = "pf := -1")
+model_elec <- fit_model(data, scale = "pf := -1", R = 1000)
 
 ## ----coef-model-elec----------------------------------------------------------
 coef(model_elec)
@@ -38,25 +40,26 @@ plot(model_elec, type = "mixture")
 set.seed(1)
 P_r <- 2
 C_true <- 3
-N <- c(100, 70, 30)
+N <- c(90, 70, 40)
 (b_true <- matrix(replicate(C_true, rnorm(P_r)), nrow = P_r, ncol = C_true))
-(Omega_true <- matrix(replicate(C_true, rwishart(P_r + 1, 0.1 * diag(P_r))$W, simplify = TRUE),
+(Omega_true <- matrix(replicate(C_true, oeli::rwishart(P_r + 1, 0.1 * diag(P_r)), simplify = TRUE),
   nrow = P_r * P_r, ncol = C_true
 ))
 beta <- c()
-for (c in 1:C_true) {
-  for (n in 1:N[c]) {
-    beta <- cbind(beta, rmvnorm(mu = b_true[, c, drop = F], Sigma = matrix(Omega_true[, c, drop = F], ncol = P_r)))
-  }
+for (c in 1:C_true) for (n in 1:N[c]) {
+  beta_n <- oeli::rmvnorm(
+    mean = b_true[, c], 
+    Sigma = matrix(Omega_true[, c, drop = F], ncol = P_r)
+  )
+  beta <- cbind(beta, beta_n)
 }
-z_true <- rep(1:3, times = N)
 
 ## ----dirichlet-prior----------------------------------------------------------
 delta <- 0.1
-xi <- numeric(P_r)
-D <- diag(P_r)
-nu <- P_r + 2
-Theta <- diag(P_r)
+mu_b_0 <- numeric(P_r)
+Sigma_b_0 <- diag(P_r)
+n_Omega_0 <- P_r + 2
+V_Omega_0 <- diag(P_r)
 
 ## ----dirichlet-inits----------------------------------------------------------
 z <- rep(1, ncol(beta))
@@ -65,17 +68,25 @@ b <- matrix(0, nrow = P_r, ncol = C)
 Omega <- matrix(rep(diag(P_r), C), nrow = P_r * P_r, ncol = C)
 
 ## ----dirichlet-process-app----------------------------------------------------
-for (r in 1:100) {
-  dp <- RprobitB:::update_classes_dp(
-    Cmax = 10, beta, z, b, Omega, delta, xi, D, nu, Theta, s_desc = TRUE
+set.seed(1)
+R <- 500
+C_seq <- numeric(R)
+for (r in seq_len(R)) {
+  dp <- update_classes_dp(
+    beta = beta, z = z, b = b, Omega = Omega, 
+    delta = delta, mu_b_0 = mu_b_0, Sigma_b_0 = Sigma_b_0, 
+    n_Omega_0 = n_Omega_0, V_Omega_0 = V_Omega_0, 
+    identify_classes = TRUE, Cmax = 10
   )
   z <- dp$z
   b <- dp$b
   Omega <- dp$Omega
+  C_seq[r] <- dp$C
 }
+table(C_seq)
 
 ## ----dirichlet-example-plot, fig.dim = c(16,8)--------------------------------
 par(mfrow = c(1, 2))
 plot(t(beta), xlab = bquote(beta[1]), ylab = bquote(beta[2]), pch = 19)
-RprobitB:::plot_class_allocation(beta, z, b, Omega, r = 100, perc = 0.95)
+plot_class_allocation(beta, z, b, Omega, r = R, perc = 0.95)
 
