@@ -5,15 +5,17 @@ test_that("choice probabilities can be computed", {
   form <- choice ~ price + time + change + comfort | 0
   data <- prepare_data(
     form = form,
-    choice_data = train_choice,
+    choice_data = train_choice[1:500, ],
     id = "deciderID",
     idc = "occasionID"
   )
   model_train <- fit_model(
     data = data,
+    R = 100,
     scale = "price := -1"
   )
-  expect_snapshot(choice_probabilities(model_train))
+  choice_probs <- choice_probabilities(model_train)
+  expect_snapshot(choice_probs)
 })
 
 test_that("creation of labels works", {
@@ -43,37 +45,39 @@ test_that("creation of labels works", {
 })
 
 test_that("choice prediction works", {
+  set.seed(1)
+  N <- 100
   data <- simulate_choices(
     form = choice ~ cost | income | time,
-    N = 50,
-    T = 1:50,
+    N = N,
+    T = sample.int(5, size = N, replace = TRUE),
     J = 2,
     alternatives = c("bus", "car"),
-    seed = 1,
     true_parameter = list("alpha" = 1:5, "Sigma" = 1)
   )
   data <- train_test(data, test_proportion = 0.3)
-  model <- fit_model(data$train, R = 1000, seed = 1)
+  model <- fit_model(data$train, R = 1000)
   expect_snapshot(predict(model, overview = TRUE))
   expect_snapshot(predict(model, overview = FALSE))
   expect_snapshot(predict(model, data = data$test, overview = TRUE))
 })
 
 test_that("preference classification works", {
+  set.seed(1)
+  N <- 100
   data <- simulate_choices(
-    form = choice ~ cost | income | time,
-    N = 30,
+    form = choice ~ cost,
+    N = N,
     T = 10,
     J = 3,
-    re = c("cost", "ASC"),
+    re = c("cost"),
     alternatives = c("train", "bus", "car"),
-    seed = 1,
-    true_parameter = list("C" = 2)
+    true_parameter = list(
+      "C" = 2, "s" = c(0.6, 0.4), "b" = matrix(c(-3, 3), ncol = 2)
+    )
   )
-  model <- fit_model(data,
-    R = 1000,
-    seed = 1,
-    latent_classes = list("C" = 2)
-  )
-  expect_snapshot(classification(model, add_true = TRUE))
+  model <- fit_model(data, latent_classes = list("C" = 2))
+  classif <- classification(model, add_true = TRUE)
+  expect_snapshot(classif)
+  # sum(classif$est == classif$true) / N
 })
